@@ -43,3 +43,8 @@ class TestTrack(unittest.TestCase):
         self.track.starred(session, set=False)
         self.assertEqual(self.track.starred(session), False)
 
+    def test_availability(self):
+        self.assertEqual(self.track.availability(), 1)
+
+    def test_is_local(self):
+        self.assertFalse(self.track.is_local())
